@@ -8,23 +8,30 @@ from functools import reduce
 def toCamelCase(s: str, user_acronyms=None):
     '''
     Camel Case Generator;
-
     Assumes you have a Pascal-cased string (e.g., TheQuickBrownFox)
     or a snake-cased string (e.g., the_quick_brown_fox)
-
     params::
     s: string
     user_acronyms: list; user-defined acronyms that should be set as such,
                         e.g., SKU, ID, etc
-
-
     Sample use:
     to_camel_case('TheQuickBrownFox', None)  # 'theQuickBrownFox'
     to_camel_case('The Quick Brown Fox', None)  # 'theQuickBrownFox'
     to_camel_case('Fru_MemorySPDSize', ['WMI', 'FRU'])  # FRUMemorySPDSize
-
     '''
 
+    def overlap_test(tpl1, tpl2):
+        a, b = np.argsort(tpl1 + tpl2)[:2] > 1
+        return a != b
+
+    def find_overlap_tuples(tpl_list):
+        result = set()
+        for test_tpl, sec_tpl in list(itertools.combinations(tpl_list, 2)):
+            if overlap_test(test_tpl, sec_tpl):
+                result.add(test_tpl)
+                result.add(sec_tpl)
+        return list(result)
+
     # handle snake_case
     if '_' in s:
         # split on snake
@@ -66,6 +73,31 @@ def toCamelCase(s: str, user_acronyms=None):
                 storage.append(out[0])
         return storage
 
+    # filter overlaps
+    def reduce_nonoverlapping_tuples(tuple_list):
+
+        def overlap_test(tpl1, tpl2):
+            a, b = np.argsort(tpl1 + tpl2)[:2] > 1
+            return a != b
+
+        def find_overlap_tuples(tpl_list):
+            result = set()
+            for test_tpl, sec_tpl in list(itertools.combinations(tpl_list, 2)):
+                if overlap_test(test_tpl, sec_tpl):
+                    result.add(test_tpl)
+                    result.add(sec_tpl)
+            return list(result)
+
+        overlapping_tuples = find_overlap_tuples(tuple_list)
+
+        def contains(a, b):
+            return a[0] >= b[0] and a[1] <= b[1] and [b] or b[0] >= a[0] and b[1] <= a[1] and [a] or [a, b]
+
+        reduced_list = sorted(reduce(lambda x, y: x[:-1] + contains(x[-1], y) if x else [y], overlapping_tuples, []))
+
+        tuple_list = sorted([t for t in set(tuple_list) if t not in overlapping_tuples] + reduced_list)
+        return tuple_list
+
     # container
     word_holder = {}
 
@@ -79,34 +111,6 @@ def toCamelCase(s: str, user_acronyms=None):
         # combine them
         acronym_positions = acronym_positions + user_acronym_positions
 
-        # filter overlaps
-        #total_acronym_positions = list(sorted(set([b if a[1] != b[1] else b for a in total_acronym_positions for b in user_acronym_positions])))
-        def reduce_nonoverlapping_tuples(tuple_list):
-
-            #tuple_list = list(set(tuple_list))
-
-            def overlap_test(tpl1, tpl2):
-                a, b = np.argsort(tpl1 + tpl2)[:2] > 1
-                return a != b
-
-            def find_overlap_tuples(tpl_list):
-                result = set()
-                for test_tpl, sec_tpl in list(itertools.combinations(tpl_list, 2)):
-                    if overlap_test(test_tpl, sec_tpl):
-                        result.add(test_tpl)
-                        result.add(sec_tpl)
-                return list(result)
-
-            overlapping_tuples = find_overlap_tuples(tuple_list)
-
-            def contains(a, b):
-                return a[0] >= b[0] and a[1] <= b[1] and [b] or b[0] >= a[0] and b[1] <= a[1] and [a] or [a, b]
-
-            reduced_list = sorted(reduce(lambda x, y: x[:-1] + contains(x[-1], y) if x else [y], overlapping_tuples, []))
-
-            tuple_list = sorted([t for t in set(tuple_list) if t not in overlapping_tuples] + reduced_list)
-            return tuple_list
-
         acronym_positions = reduce_nonoverlapping_tuples(acronym_positions)
 
     # find acronyms from positions
@@ -141,6 +145,9 @@ def toCamelCase(s: str, user_acronyms=None):
     # get pascal text given extracted positions
     pascal_chars = [s[pos[0]: pos[1]] for pos in pascal_positions]
 
+    # deal with periods; needs a more elegant approach
+    pascal_chars = [s.replace('.', '') for s in pascal_chars]
+
     # what we have given our user acronyms so we do not double count
     for i, (char, pos) in enumerate(zip(pascal_chars, pascal_positions)):
         # if we find the word in what acronyms already found
@@ -150,13 +157,10 @@ def toCamelCase(s: str, user_acronyms=None):
             pascal_positions.pop(i)
 
     # find text that is lowercase and is followed by lowercase, start of str
-    starting_chars = [re.findall(r'\b[a-z][a-z]+', s)]
+    starting_positions = [(m.start(0), m.end(0)) for m in re.finditer(r'\b[a-z][a-z]+', s.replace('.', ''))]
 
-    # collapse list
-    starting_chars = sum(starting_chars, [])
-
-    # find starting text positions
-    starting_positions = [(m.start(0), m.end(0)) for m in re.finditer(r'\b[a-z][a-z]+', s)]
+    # get the characters
+    starting_chars = [s[pos[0]: pos[1]] for pos in starting_positions]
 
     # find last pos
     last_pos = len(s)
@@ -165,6 +169,18 @@ def toCamelCase(s: str, user_acronyms=None):
     for a_pos, a_word in zip(acronym_positions, acronyms):
         word_holder[a_pos] = a_word
 
+    # find overlapping tuples that occur with acronym and pascal searches
+    combined_tuples = sorted(list(word_holder.keys()) + pascal_positions)
+    non_overlapping_tuples = reduce_nonoverlapping_tuples(combined_tuples)
+    found_overlaps = find_overlap_tuples(combined_tuples)
+    non_overlapping_tuples = [t for t in found_overlaps if t in pascal_positions]
+
+    # get indices for new pascal_chars
+    indices_of_interest = [pascal_positions.index(t) for t in pascal_positions if t not in non_overlapping_tuples]
+    pascal_chars = [pascal_chars[i] for i in indices_of_interest]
+    # update pascal positions
+    pascal_positions = [t for t in pascal_positions if t not in non_overlapping_tuples]
+
     # store positions and text
     for p_pos, p_word in zip(pascal_positions, pascal_chars):
         # if the starting word is pascal; lower it
@@ -172,6 +188,8 @@ def toCamelCase(s: str, user_acronyms=None):
             p_word = p_word.lower()
             word_holder[p_pos] = p_word
         else:
+            # capitalize any extras that tagged along
+            p_word = p_word.capitalize()
             word_holder[p_pos] = p_word
 
     # store postions and text
