@@ -27,7 +27,10 @@ s8 = 'L5_Board_Serial_Number'
 s9 = 'Power Load (40%)'
 s10 = 'iaasByMicrosoft'
 s11 = 'ASECRCqaasAutomation'
-
+s12 = 'Custom.CHMEFactoryManufacturing.inactive'
+s13 = 'Custom.CHMEFactoryManufacturing.inactive.active.test'
+s14 = 'ExtOFR_6XXXX'
+s15 = 'WEF_282A0B617F404B78BFAA7DD05BE6AB04_System.ExtensionMarker'
 
 
 if __name__ == '__main__':
@@ -55,4 +58,9 @@ if __name__ == '__main__':
 	assert cc.toCamelCase(s9, ['WMI', 'FRU', 'SKU', 'UEFI']) == 'powerLoad40', 'failed'
 	assert cc.toCamelCase(s10, ['IaaS']) == 'IaaSByMicrosoft', 'failed'
 	assert cc.toCamelCase(s11, ['ASECRC', 'QaaS']) == 'ASECRCQaaSAutomation', 'failed'
+	assert cc.toCamelCase(s12, ['WMI', 'FRU']) == 'customCHMEFactoryManufacturingInactive', 'failed'
+	assert cc.toCamelCase(s13, ['WMI', 'FRU']) == 'customCHMEFactoryManufacturingInactiveActiveTest', 'failed'
+	assert cc.toCamelCase(s14, None) == 'extOFR6XXXX', 'failed'
+	assert cc.toCamelCase(s15, None) == 'WEF282A0B617F404B78BFAA7DD05BE6AB04SystemExtensionMarker', 'failed'
+
 	print('all tests passed!')
